Default executor using Task.Supervisor.async_nolink.
This is the zero-overhead default. The Worker's dispatch loop delegates to this executor when no custom executor is configured.
Default executor using Task.Supervisor.async_nolink.
This is the zero-overhead default. The Worker's dispatch loop delegates to this executor when no custom executor is configured.