Runic.Workflow.FanOut (Runic v0.1.0-alpha.7)

Copy Markdown View Source

FanOut steps are part of a map operator that expands enumerable facts into separate facts.

FanOut just splits input facts - separate steps as defined in the map expression will do the processing.